/*
--Tecnisa - Tecnologia em Informtica
--
--Nome: EXPORTA_NUTRIENTES
--
--Descrio:
--  Procedure usada no programa GER04001 - Cpia de nutrientes.
--  Copia os nutrientes de um produtos para vrios outros,
--  sobrepondo os atuais ou acrescentando os novos.
--Criao:
--04/04/2001 - Dmaso
--
--@C:\win_ver\sql\oracle\7150_PLASTP_EXPORTA_NUTRIENTES.SQL

Parmetros:
  P_CDPRODORIG -- Cdigo do produto de origem
  P_LISTANUTR -- Lista dos nutrientes de origem (que sero copiados)
  P_LISTAPROD -- Lista dos produtos de destino (que sero modificados)
  P_OPERACAO -- 'A' --> ACRESCENTAR
             -- 'S' --> SOBREPOR

*/
CREATE OR REPLACE PROCEDURE EXPORTA_NUTRIENTES
(P_CDPRODORIG IN VARCHAR2,
 P_LISTANUTR  IN VARCHAR2,
 P_LISTAPROD  IN VARCHAR2,
 P_OPERACAO   IN VARCHAR2
)
IS
BEGIN

   FOR C_PRODDEST IN
   /* Seleciona os produtos de destino */
   (SELECT
       DISTINCT CDPRODUTO
    FROM
       PRODUTO, LISTA
    WHERE
       (CDARVPROD <> P_CDPRODORIG  ) AND
       (CDPRODUTO =  CDPRODESTO    ) AND
       (CDARVPROD =  LISTA.CDLISTA ) AND
       (LISTA.NRLISTA = P_LISTAPROD)) LOOP

       /* OPERACAO = ACRESCENTAR Nutrientes */
       IF P_OPERACAO = 'A' THEN
       /* Seleciona os nutrientes do produto origem */
       /* que o destino nao tenha                   */
          FOR C_NUTRIENTES IN
          (SELECT
              O.CDPRODUTO,
              O.CDNUTRIENTE,
              O.QTNUTRPROD,
              O.DSFONTNUTR
           FROM
              NUTRPROD O, PRODUTO P
           WHERE
              (P.CDPRODUTO = O.CDPRODUTO)    AND
              (P.CDARVPROD = P_CDPRODORIG) AND
              (INSTR(P_LISTANUTR, O.CDNUTRIENTE) > 0) AND
               NOT O.CDNUTRIENTE IN (SELECT D.CDNUTRIENTE
                                     FROM NUTRPROD D
                                     WHERE
                                    (D.CDPRODUTO = C_PRODDEST.CDPRODUTO) AND
                                    (D.CDNUTRIENTE = O.CDNUTRIENTE)))
          LOOP
          /* Acrescenta os novos nutrientes */
              INSERT INTO NUTRPROD
              (CDPRODUTO, CDNUTRIENTE, QTNUTRPROD, DSFONTNUTR)
              VALUES
              (C_PRODDEST.CDPRODUTO, C_NUTRIENTES.CDNUTRIENTE, C_NUTRIENTES.QTNUTRPROD, C_NUTRIENTES.DSFONTNUTR);

          END LOOP;
       END IF;

       /* OPERACAO = SUBSTITUIR Nutrientes */
       IF P_OPERACAO = 'S' THEN
       /* Deleta os nutrientes do produto */
          DELETE FROM NUTRPROD
          WHERE CDPRODUTO = C_PRODDEST.CDPRODUTO;

       /* Seleciona os nutrientes do produto de origem */
          FOR C_NUTRIENTES IN
          (SELECT
              NP.CDPRODUTO,
              NP.CDNUTRIENTE,
              NP.QTNUTRPROD,
              NP.DSFONTNUTR,
              PR.CDARVPROD
           FROM
              NUTRPROD NP, PRODUTO PR
           WHERE
              (PR.CDPRODUTO = NP.CDPRODUTO) AND
              (PR.CDARVPROD = P_CDPRODORIG) AND
              (INSTR(P_LISTANUTR, CDNUTRIENTE) > 0)) LOOP

       /* Insere nutriente por nutriente no produto de destino */
             INSERT INTO NUTRPROD
             (CDPRODUTO, CDNUTRIENTE, QTNUTRPROD, DSFONTNUTR)
             VALUES
             (C_PRODDEST.CDPRODUTO, C_NUTRIENTES.CDNUTRIENTE, C_NUTRIENTES.QTNUTRPROD, C_NUTRIENTES.DSFONTNUTR);

          END LOOP;
       END IF;
   END LOOP;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('EXPORTA_NUTRIENTES','4.06.040'); END;
/

