function PercentAjustmentController(General, MessageService, ScreenService, PercentAjustmentService, templateManager) {
    
    this.setDataSourceFilter = function(args) {
        const row = args.e.preference.FILTER_ROW;
        const widget = args.owner;
        
        if(widget.isValid() && isValidFilterProducts(row.CDARVPRODINI, row.CDARVPRODFIN)) {
            widget.dataSourceFilter = [
    		    {
    		        "name": "P_CDFILIAL",
    		        "operator": "=",
    		        "value": row.CDFILIAL
    		    },
    		    {
    		        "name": "P_CDARVPRODINI",
    		        "operator": "=",
    		        "value": row.CDARVPRODINI
    		    },
    		    {
    		        "name": "P_CDARVPRODFIN",
    		        "operator": "=",
    		        "value": row.CDARVPRODFIN
    		    },
    		    {
                    "operator": "ORDER_BY",
                    "name": [
                        {
                            "name": "CDARVPROD",
                            "direction": "ASC"
                        }
                    ]
                }
    		];
    		
    		setStripeValues(row);
    		
    		//widget.getAction('CADAUTO').readOnly = widget.appliedFilter.ID == 'ORIGINAL' ? true : false;
    		//widget.getAction('ALTERAUTO').readOnly = widget.appliedFilter.ID == 'ORIGINAL' ? true : false;
    		
    		widget.activate();
        }
    };
    
    function isValidFilterProducts(productStart, productEnd) {
        if (!General.comparaPratoProduto(productStart, productEnd, getLocalVar('CDPICTPROD'))) {
            MessageService.showMessageByCode("INIPRODUCT_MUSTBELESSTHAN_FINPRODUCT", null, Constants.infoMessage);
            return false;
        }

        return true;
    }
    
    function setStripeValues(row) {
        const stripeWidget = templateManager.container.getWidget('stripe');
        
        stripeWidget.currentRow.CDFILIAL  = row.CDFILIAL.concat(' - ').concat(row.NMFILIAL);
        stripeWidget.currentRow.CDPRODINI = row.CDARVPRODINI.concat(' - ').concat(row.NMPRODINI);
        stripeWidget.currentRow.CDPRODFIN = row.CDARVPRODFIN.concat(' - ').concat(row.NMPRODFIN);
        stripeWidget.currentRow.FILTER_CDFILIAL = row.CDFILIAL;
        stripeWidget.currentRow.FILTER_NMFILIAL = row.NMFILIAL;
    }
    
    this.updatePercentAdjustments = function() {
    	const widgetProducts = templateManager.container.getWidget('products');
    	const row = widgetProducts.currentRow;
    	
		vrDescValidation(row);
		
		MessageService.confirmMessageByCode("CONFIRM_OPERATION", null, Constants.confirmationMessage).then(function(success) {
    		PercentAjustmentService.updatePercentAdjustments(row).then(function() {
    		    MessageService.successNotificationByCode('SUCCESS_OPERATION');
                widgetProducts.reload();
                widgetProducts.list();
            }).catch(function(error) {
            	showErrorMessage(error);
            });
        }.bind(this));
    };
    
    function showErrorMessage(error) {
    	var errorMessage = "TIMEOUT";
        let textContentError = '';
        
        if (error.data){
            errorMessage = "ERR_GENERICO";
            textContentError = error.data.error;
        }
        
        MessageService.showMessageByCode(errorMessage, {"PARAM":textContentError}, Constants.errorMessage);
    }
    
    this.cancelInlineEdit = function() {
        const widgetProducts = templateManager.container.getWidget('products');
        
        widgetProducts.rollbackInlineEdit();
        widgetProducts.list();
    };
    
    this.deleteAdjustment = function(args) {
        const widgetProducts = templateManager.container.getWidget('products');
        
        MessageService.confirmMessageByCode("CONFIRM_DELETE", null, Constants.confirmationMessage).then(function(success) {
            let produtoArray = [];
            
            widgetProducts.dataSource.data.forEach(function(row) {
                if (row.__isSelected) {
                    produtoArray.push(row);
                }
            });
	
            PercentAjustmentService.deletePercentAdjustments(produtoArray).then(function() {
                MessageService.successNotificationByCode('SUCCESS_OPERATION');
                widgetProducts.unSelectAll();
                widgetProducts.reload();
                widgetProducts.activate();
            }).catch(function(error) {
            	showErrorMessage(error);
            });
        });
    };
    
    this.openPopupWidget = function(widgetName) {
        const widget = templateManager.container.getWidget(widgetName);
        const stripeWidget = templateManager.container.getWidget('stripe');
        
        ScreenService.openPopup(widget).then(function(success){
            widget.currentRow.CDFILIAL = stripeWidget.currentRow.FILTER_CDFILIAL;
            widget.currentRow.NMFILIAL = stripeWidget.currentRow.FILTER_NMFILIAL;
        	widget.edit();
        }); 
    };
    
    this.addAdjustment = function(args) {
        const widgetProducts = templateManager.container.getWidget('products');
    	const row = args.owner.widget.currentRow;
    	
		vrDescValidation(row);
		
		if(widgetProducts.dataSource.data.filter(data => data.CDFILIAL == row.CDFILIAL && data.CDPRODUTO == row.CDPRODUTO).length) {
			MessageService.showMessageByCode('ALREADY_REGISTERED', null, Constants.infoMessage);
		} else {
		    PercentAjustmentService.addPercentAdjustments(row).then(function() {
				ScreenService.closePopup();
				MessageService.successNotificationByCode('SUCCESS_OPERATION');
				widgetProducts.reload();
				widgetProducts.activate();
			}).catch(function(error) {
				showErrorMessage(error);
			});	
		}
    };
    
    function vrDescValidation(row) {
        if(parseFloat(row.VRPERCENTDESCONTO) >= 100) {
			return MessageService.showMessageByCode("VALID_VRPERCENTDESCONTO", null, Constants.infoMessage);		
		}
    }
    
    this.backSwipe = function(args) {
    	args.owner.widget.currentRow = {};
    	ScreenService.closePopup();
    };
}

Configuration(function(ContextRegister) {
    ContextRegister.register('PercentAjustmentController', PercentAjustmentController);
});